@@ -1,8 +1,8 @@
 from nonebot.plugin import PluginMetadata
 
-from .__main__ import *  # noqa
+from .main import *  # noqa
 
-__version__ = "0.3.2"
+__version__ = "0.3.5"
 __plugin_meta__ = PluginMetadata(
     "HistoryBanner",
     "这是一个在机器人上获取原神历史卡池的插件",
